#
# spec file for package prometheus-hanadb_exporter
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%if 0%{?suse_version} < 1500
%bcond_with test
%else
%bcond_without test
%endif

%define _prefix /usr
%define oldsyscondir /etc
%define _sysconfdir %{_prefix}/etc
%define pythons python3

%{?!python_module:%define python_module() python3-%{**}}
Name:           prometheus-hanadb_exporter
Version:        0.8.0+git.1681379025.bf6cd7c
Release:        150200.3.9.1
Summary:        SAP HANA database metrics exporter
License:        Apache-2.0
Group:          System/Monitoring
URL:            https://github.com/SUSE/hanadb_exporter
Source:         %{name}-%{version}.tar.gz
%if %{with test}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module boto3}
BuildRequires:  %{python_module certifi}
%endif
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
Provides:       hanadb_exporter = %{version}-%{release}
BuildRequires:  fdupes
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
Requires:       %{python_module prometheus_client} >= 0.6.0
Requires:       %{python_module shaptools}
Requires:       %{python_module boto3}
Recommends:     %{python_module certifi}
BuildArch:      noarch

%description
SAP HANA database metrics exporter

%define shortname hanadb_exporter

%prep
%setup -q -n %{name}-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
# do not install tests
%python_expand rm -r %{buildroot}%{$python_sitelib}/tests

# Add daemon files
mkdir -p %{buildroot}%{oldsyscondir}/%{shortname}
mkdir -p %{buildroot}%{_sysconfdir}/%{shortname}
install -D -m 644 daemon/%{shortname}@.service %{buildroot}%{_unitdir}/%{name}@.service

install -D -m 0644 config.json.example %{buildroot}%{_docdir}/%{name}/config.json.example
install -D -m 0644 metrics.json %{buildroot}%{_docdir}/%{name}/metrics.json
install -D -m 0644 logging_config.ini %{buildroot}%{_docdir}/%{name}/logging_config.ini

%post
%service_add_post %{name}@.service
rm -rf  %{_sysconfdir}/%{shortname}/*
ln -s %{_docdir}/%{name}/config.json.example %{_sysconfdir}/%{shortname}/config.json.example
ln -s %{_docdir}/%{name}/metrics.json  %{_sysconfdir}/%{shortname}/metrics.json
ln -s %{_docdir}/%{name}/logging_config.ini  %{_sysconfdir}/%{shortname}/logging_config.ini

%pre
%service_add_pre %{name}@.service

%preun
%service_del_preun %{name}@.service

%postun
%service_del_postun %{name}@.service

%if %{with test}
%check
pytest tests
%endif

%files
%defattr(-,root,root,-)
%if 0%{?sle_version:1} && 0%{?sle_version} < 120300
%doc README.md docs/METRICS.md LICENSE
%else
%doc README.md docs/METRICS.md
%license LICENSE
%endif
%{python_sitelib}/*
%{_bindir}/%{shortname}

%dir %{_sysconfdir}
%dir %{oldsyscondir}/%{shortname}
%dir %{_sysconfdir}/%{shortname}
%{_docdir}/%{name}/config.json.example
%{_docdir}/%{name}/metrics.json
%{_docdir}/%{name}/logging_config.ini
%{_unitdir}/%{name}@.service

%changelog
* Tue May  2 2023 UTC - shap-staff@suse.de
- Release 0.8.0
  Addresses bsc#1210869
  [#]# What's Changed
  * Use systemd notify to set correctly the READY state by @arbulu89 in https://github.com/SUSE/hanadb_exporter/pull/86
  * Fix daemon flag usage by @arbulu89 in https://github.com/SUSE/hanadb_exporter/pull/87
  * Implement the version flag by @arbulu89 in https://github.com/SUSE/hanadb_exporter/pull/89
  * Update db_manager.py by @karolyczovek in https://github.com/SUSE/hanadb_exporter/pull/90
  * Fixing empty system replication panel 91#issue-918975015 by @pirat013 in https://github.com/SUSE/hanadb_exporter/pull/92
  * Add AWS Secrets Manager support by @elturkym in https://github.com/SUSE/hanadb_exporter/pull/97
  * Fix Boto3 dependency introduced by PR#97 by @diegoakechi in https://github.com/SUSE/hanadb_exporter/pull/98
  * Add config option 'listen_address' by @fjnalta in https://github.com/SUSE/hanadb_exporter/pull/99
  * update spec file to python packaging best practices by @yeoldegrove in https://github.com/SUSE/hanadb_exporter/pull/101
  * Enable ssl connection by @arbulu89 in https://github.com/SUSE/hanadb_exporter/pull/96
  * Fix the unittest fixing pytest to version 6 by now by @arbulu89 in https://github.com/SUSE/hanadb_exporter/pull/103
  * Remove invalid trailing comma from example file by @arbulu89 in https://github.com/SUSE/hanadb_exporter/pull/108
  * IMDSv1 and IMDSv2 abstraction for the retrieval of HANA DB Credentials from AWS Secrets Manager by @schniber in https://github.com/SUSE/hanadb_exporter/pull/112
  [#]# New Contributors
  * @karolyczovek made their first contribution in https://github.com/SUSE/hanadb_exporter/pull/90
  * @pirat013 made their first contribution in https://github.com/SUSE/hanadb_exporter/pull/92
  * @elturkym made their first contribution in https://github.com/SUSE/hanadb_exporter/pull/97
  * @fjnalta made their first contribution in https://github.com/SUSE/hanadb_exporter/pull/99
  * @yeoldegrove made their first contribution in https://github.com/SUSE/hanadb_exporter/pull/101
  * @schniber made their first contribution in https://github.com/SUSE/hanadb_exporter/pull/112
  * *Full Changelog**: https://github.com/SUSE/hanadb_exporter/compare/0.7.3...0.8.0
* Mon Nov  2 2020 UTC - shap-staff@suse.de
- Release 0.7.3
  - Fix systemd macros usage in spec file (https://github.com/SUSE/hanadb_exporter/pull/81)
  (bsc#1178339)
* Thu Oct  1 2020 UTC - shap-staff@suse.de
- Release 0.7.2
  [#] Added
  - lookup for `/usr/etc` and  the fallback `/etc` directory for config files. ( https://github.com/SUSE/hanadb_exporter/pull/78)
* Tue May  5 2020 xarbulu@suse.com
- Version 0.7.1 Fix the case where HELP and TYPE entries are exported
  even though there is not any record for that metric (bsc#1170717)
  (jsc#SLE-10902, jsc#SLE-10903, jsc#ECO-817, jsc#ECO-818)
* Wed Apr 29 2020 julien.adamek@suse.com
- Fix and improve the README file (bsc#1170843)
* Tue Feb 11 2020 xarbulu@suse.com
- Version 0.7.0 created
- Rename the rpm package to prometheus-hanadb_exporter to follow
  the prometheus conventions
- Update the default port from 8001 to 9668
  (jsc#SLE-10545)
* Wed Jan 15 2020 xarbulu@suse.com
- Version 0.6.1 Fix use case where TENANT_DATA_QUERY query
  returns columns with invalid values (0 number)
* Tue Dec 10 2019 xarbulu@suse.com
- Version 0.6.0 Change configuration files location from /etc
  to /usr/etc
* Tue Dec 10 2019 xarbulu@suse.com
- Version 0.5.3 Improve metrics collection if some of the rows
  result is None. Before, if any result was None the result was
  not exported. Now, only metrics with None value are ommitted
* Mon Dec  9 2019 xarbulu@suse.com
- Version 0.5.2 Add the option to use the hanadb_exporter with
  the stored user key. This gives the option to avoid the plain
  user/password strings usage.
* Wed Nov  6 2019 dakechi@suse.com
- Version 0.5.1 Add the SAP HANA current alerts rating metric.
  This metric expose the current triggered alerts coming from
  inside the database and the rating (severity) of them. The rating
  is classified between 1 and 5.
* Fri Oct 25 2019 xarbulu@suse.com
- Version 0.5.0 Add the option to export metrics from multiple
  databases/tenants
* Thu Oct 24 2019 xarbulu@suse.com
- Version 0.4.1 Add new metadata labels to the metrics (sid, instance
  number and databse name)
* Wed Oct 23 2019 xarbulu@suse.com
- Version 0.4.0 Remove the factory usage to gain simplicity as only
  the prometheus exporter is used
* Tue Oct 22 2019 xarbulu@suse.com
- Version 0.3.4 Add reconnection to the database to avoid issues
  when the hana database is stopped and restarted
* Wed Aug  7 2019 abelarbi@suse.de
- Version 0.3.3 Better handling of query failures and incorrect labels
  and values
* Tue Jul  9 2019 xarbulu@suse.com
- Version 0.3.2 adding the option to filter the queries by current
  SAP HANA database version
* Wed Jul  3 2019 xarbulu@suse.com
- Version 0.3.1 updating how the exporter is executed as a daemon
* Tue Jul  2 2019 xarbulu@suse.com
- Version 0.3.0 created
- Code to manage the metrics updated to have a more generic usage
- metrics.json file structure updated to add more additional information
- Documentation created to explain how to create/update the metrics.json
  file
* Mon Jul  1 2019 xarbulu@suse.com
- Version 0.2.2 created with a new logging system
* Wed Jun 19 2019 xarbulu@suse.com
- Version 0.2.1 created
- Systemd support added to daemonize the execution
* Thu Jun 13 2019 xarbulu@suse.com
- Version 0.2.0 created
- Improve the hanadb_exporter to retreive the metrics data from a
  configuration file
- Label correctly the imported metrics
* Wed Jun 12 2019 xarbulu@suse.com
- First package version 0.1.0
